package com.jd.health.insurance.open.export.util;

import java.math.BigInteger;
import java.nio.charset.StandardCharsets;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

/**
 * @description : Sha256 工具类
 * @author : liuJunFei5
 * @date : 2021-08-13 18:37:51
 * @version : 1.0
 */
public class Sha256 {

    /**
     * 长度
     */
    private static final int STR_LENGTH = 64;

    /**
     * getSHA
     *
     * @param input
     * @return
     * @throws NoSuchAlgorithmException
     */
    private static byte[] getSha(String input) throws NoSuchAlgorithmException {
        // Static getInstance method is called with hashing SHA
        MessageDigest md = MessageDigest.getInstance("SHA-256");
        // digest() method called
        // to calculate message digest of an input
        // and return array of byte
        return md.digest(input.getBytes(StandardCharsets.UTF_8));
    }

    /**
     * 获得Sha256的摘要值
     *
     * @param param
     * @return
     */
    public static String toShaString(String param) {
        if (param == null) {
            return null;
        }
        try {
            byte[] hash = getSha(param);
            // Convert byte array into signum representation
            BigInteger number = new BigInteger(1, hash);
            // Convert message digest into hex value
            StringBuilder hexString = new StringBuilder(number.toString(16));
            // Pad with leading zeros
            while (hexString.length() < STR_LENGTH) {
                hexString.insert(0, '0');
            }
            return hexString.toString();
        } catch (NoSuchAlgorithmException e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * main test
     *
     * @param args
     */
    public static void main(String[] args) {
        try {
            System.out.println("HashCode Generated by SHA-256 for:");
            String s1 = "TEST1";
            System.out.println("\n" + s1 + " : " + toShaString(s1));
            String s2 = "TEST2";
            System.out.println("\n" + s2 + " : " + toShaString(s2));
        } catch (Exception e) {
            System.out.println("Exception thrown for incorrect algorithm: " + e);
        }
    }
}